var group__plugType =
[
    [ "kFx", "group__plugType.html#ga81395ffc74210c6b129ac5c1ad0f0450", null ],
    [ "kFxAnalyzer", "group__plugType.html#ga0017ff4ab459880956723e09c847188a", null ],
    [ "kFxBass", "group__plugType.html#ga27b925ffb4f7d3da798f2b446fe06538", null ],
    [ "kFxChannelStrip", "group__plugType.html#ga5a54a33f151d3d0068d43d377fbacaea", null ],
    [ "kFxDelay", "group__plugType.html#ga377e6c632bbed63329ad118e1d1f6780", null ],
    [ "kFxDistortion", "group__plugType.html#gad8da16bef223355cc58d3b469f876b33", null ],
    [ "kFxDrums", "group__plugType.html#ga7cc4c653b53d167ebf833dc4bcd373ba", null ],
    [ "kFxDynamics", "group__plugType.html#ga9584914ab8362461d1bb4bac52ab9fd9", null ],
    [ "kFxEQ", "group__plugType.html#ga9dbf945372efb065d5f47af0aed0c498", null ],
    [ "kFxFilter", "group__plugType.html#gaf145d8e7f4ba5cf0b6f8d1373647451f", null ],
    [ "kFxGenerator", "group__plugType.html#gafe3ff646d102a4209512d6cda3b62ac4", null ],
    [ "kFxGuitar", "group__plugType.html#ga5d7f914faef6c2a37eea292a7b16c76f", null ],
    [ "kFxInstrument", "group__plugType.html#gad632f4944a960678d6ff9b3886c878db", null ],
    [ "kFxInstrumentExternal", "group__plugType.html#ga0280f4b9390e12bf4b4846515572694a", null ],
    [ "kFxMastering", "group__plugType.html#ga6e00e778267b163458d145a6b6ac37b1", null ],
    [ "kFxMicrophone", "group__plugType.html#gada3df3cb9ee2283e1dbae231d9d18644", null ],
    [ "kFxModulation", "group__plugType.html#ga2aea8d0a0d5d5e40680ce5260f52dafd", null ],
    [ "kFxNetwork", "group__plugType.html#gab2264c85ad07f983f365ca1c53489fe3", null ],
    [ "kFxPitchShift", "group__plugType.html#ga0759e804603c37125d02cbc3b091f03b", null ],
    [ "kFxRestoration", "group__plugType.html#ga4dd95a64193b078cc91d160ae39a95ed", null ],
    [ "kFxReverb", "group__plugType.html#ga01b7fd148c1e5aefa3ea548be3257e50", null ],
    [ "kFxSpatial", "group__plugType.html#gab77fa9595f5503b0d5a49407e1a918c7", null ],
    [ "kFxSurround", "group__plugType.html#gaf9b7f8cfe416744097bfcddfdcced2e6", null ],
    [ "kFxTools", "group__plugType.html#ga658d80d06b44b28d34628e66c2f1e4e3", null ],
    [ "kFxVocals", "group__plugType.html#ga0091b72150adc715454c410d230127e9", null ],
    [ "kInstrument", "group__plugType.html#gac380562898ec7144f4e0ee3b4baa6aa3", null ],
    [ "kInstrumentDrum", "group__plugType.html#ga793ad8a6c605423f8ca78e6bfacd8e22", null ],
    [ "kInstrumentExternal", "group__plugType.html#ga2dd44f3dc1709680a63b597bac817796", null ],
    [ "kInstrumentPiano", "group__plugType.html#gadceab87ecf367542d41be60acbdf1f6a", null ],
    [ "kInstrumentSampler", "group__plugType.html#gadf71323f9881f84038a18a55f9c5693b", null ],
    [ "kInstrumentSynth", "group__plugType.html#gaadec73a763ae5856f94a1d0ad1335d58", null ],
    [ "kInstrumentSynthSampler", "group__plugType.html#gaffed7482d7d1551379ad26515f4816ef", null ],
    [ "kAmbisonics", "group__plugType.html#gae0aa5ea7deb453d05ae4a38612d30868", null ],
    [ "kAnalyzer", "group__plugType.html#gaf0d4b7073ef26a60cedee77e04e9f94f", null ],
    [ "kNoOfflineProcess", "group__plugType.html#gaa5ff5ac3ea4de85f61375ed04b2ab88a", null ],
    [ "kOnlyARA", "group__plugType.html#gab1fff222e0c2b65ce6574afa48e3b838", null ],
    [ "kOnlyOfflineProcess", "group__plugType.html#gac5a7bb9551dc86a93bc764efef832164", null ],
    [ "kOnlyRealTime", "group__plugType.html#ga5c37de66c8a6ede53f92d9ea117bbd50", null ],
    [ "kSpatial", "group__plugType.html#ga6a5beaeb94b8e0a215026ac95f44a6ab", null ],
    [ "kSpatialFx", "group__plugType.html#ga0ab3065d837d3ed2cb309b61e43e7590", null ],
    [ "kUpDownMix", "group__plugType.html#ga96b0fa2b93633f94d256d0926a23216f", null ],
    [ "kMono", "group__plugType.html#gabd5da3c6aa4168e82cf36eb2c42fac1e", null ],
    [ "kStereo", "group__plugType.html#ga74b483d71fbc43888e605cfdf8b69bd3", null ],
    [ "kSurround", "group__plugType.html#ga1cbb72f7fd4c011b07e0a249228e54ac", null ]
];